@@ -32,11 +32,11 @@ class Sensor:
     factor = attr.ib(default=None)
     path = attr.ib(default=None)
     value = attr.ib(default=None, init=False)
-    key_idx = attr.ib(default=0, repr=False, init=False)
+    key_idx = attr.ib(default="0", repr=False, init=False)
 
     def __attrs_post_init__(self):
         """Init path."""
-        idx = 0
+        idx = "0"
         key = str(self.key)
         if key[-2] == "_" and key[-1].isdigit():
             idx = key[-1]
@@ -105,7 +105,11 @@ class Sensors:
             self.add(
                 (
                     # AC side - Grid measurements
+                    #   grid_power = power_l1 + power_l2 + power_l3
                     Sensor("6100_40263F00", "grid_power", "W"),
+                    Sensor("6100_40464000", "power_l1", "W"),
+                    Sensor("6100_40464100", "power_l2", "W"),
+                    Sensor("6100_40464200", "power_l3", "W"),
                     Sensor("6100_00465700", "frequency", "Hz", 100),
                     Sensor("6100_00464800", "voltage_l1", "V", 100),
                     Sensor("6100_00464900", "voltage_l2", "V", 100),
@@ -113,17 +117,13 @@ class Sensors:
                     Sensor("6100_40465300", "current_l1", "A", 1000),
                     Sensor("6100_40465400", "current_l2", "A", 1000),
                     Sensor("6100_40465500", "current_l3", "A", 1000),
-                    Sensor("6100_40464000", "power_l1", "W"),
-                    Sensor("6100_40464100", "power_l2", "W"),
-                    Sensor("6100_40464200", "power_l3", "W"),
                     # DC side - PV Generation
-                    Sensor("6100_0046C200", "pv_power", "W"),
+                    #   Power form the panels: pv_power_a (similar to old pv_power)
+                    #   Old 6100_0046C200 is the power generated by the inverter (always equal to grid_power)
                     Sensor("6380_40251E00_0", "pv_power_a", "W"),
                     Sensor("6380_40251E00_1", "pv_power_b", "W"),
-                    Sensor("6380_40451F00", "pv_voltage", "V", 100),
                     Sensor("6380_40451F00_0", "pv_voltage_a", "V", 100),
                     Sensor("6380_40451F00_1", "pv_voltage_b", "V", 100),
-                    Sensor("6380_40452100", "pv_current", "A", 1000),
                     Sensor("6380_40452100_0", "pv_current_a", "A", 1000),
                     Sensor("6380_40452100_1", "pv_current_b", "A", 1000),
                     Sensor("6400_0046C300", "pv_gen_meter", "kWh", 1000),
@@ -186,7 +186,7 @@ class Sensors:
             self.__s.remove(old)
             _LOGGER.warning("Replacing sensor %s with %s", old, sensor)
 
-        if sensor.key in self and self[sensor.key].key_idx is sensor.key_idx:
+        if sensor.key in self and self[sensor.key].key_idx == sensor.key_idx:
             _LOGGER.warning(
                 "Duplicate SMA sensor key %s (idx: %s)", sensor.key, sensor.key_idx
             )
